@@ -3,7 +3,7 @@
 # :Author: David Goodger, Günter Milde
 #          Based on the html4css1 writer by David Goodger.
 # :Maintainer: docutils-develop@lists.sourceforge.net
-# :Revision: $Revision: 8412 $
+# :Revision: $Revision: 8644 $
 # :Date: $Date: 2005-06-28$
 # :Copyright: © 2016 David Goodger, Günter Milde
 # :License: Released under the terms of the `2-Clause BSD license`_, in short:
@@ -13,13 +13,15 @@
 #    notice and this notice are preserved.
 #    This file is offered as-is, without any warranty.
 #
-# .. _2-Clause BSD license: http://www.spdx.org/licenses/BSD-2-Clause
+# .. _2-Clause BSD license: https://opensource.org/licenses/BSD-2-Clause
 
 """common definitions for Docutils HTML writers"""
 
-import sys
-import os.path
+import base64
+import mimetypes
+import os, os.path
 import re
+import sys
 
 try: # check for the Python Imaging Library
     import PIL.Image
@@ -166,7 +168,7 @@ class HTMLTranslator(nodes.NodeVisitor):
 
     head_prefix_template = ('<html xmlns="http://www.w3.org/1999/xhtml"'
                             ' xml:lang="%(lang)s" lang="%(lang)s">\n<head>\n')
-    content_type = ('<meta charset="%s"/>\n')
+    content_type = '<meta charset="%s"/>\n'
     generator = ('<meta name="generator" content="Docutils %s: '
                  'http://docutils.sourceforge.net/" />\n')
 
@@ -242,7 +244,7 @@ class HTMLTranslator(nodes.NodeVisitor):
         Used by visit_* and depart_* functions in conjunction with the tree
         traversal. Make sure that the pops correspond to the pushes."""
 
-        self.topic_classes = [] # TODO: replace with self_in_contents
+        self.topic_classes = []
         self.colspecs = []
         self.compact_p = True
         self.compact_simple = False
@@ -310,7 +312,7 @@ class HTMLTranslator(nodes.NodeVisitor):
                                        encoding='utf-8').read()
                 self.settings.record_dependencies.add(path)
             except IOError as err:
-                msg = u"Cannot embed stylesheet '%s': %s." % (
+                msg = u"Cannot embed stylesheet '%r': %s." % (
                                 path, SafeString(err.strerror))
                 self.document.reporter.error(msg)
                 return '<--- %s --->\n' % msg
@@ -512,8 +514,9 @@ class HTMLTranslator(nodes.NodeVisitor):
         if (isinstance(node, (nodes.enumerated_list, nodes.bullet_list))
             and not self.settings.compact_lists):
             return False
-        # more special cases:
-        if (self.topic_classes == ['contents']): # TODO: self.in_contents
+        # Table of Contents:
+        if (self.topic_classes == ['contents']):
+            # TODO: look in parent nodes, remove self.topic_classes?
             return True
         # check the list items:
         return self.check_simple_list(node)
@@ -538,14 +541,15 @@ class HTMLTranslator(nodes.NodeVisitor):
     def depart_caption(self, node):
         self.body.append('</p>\n')
 
-    # citations
-    # ---------
-    # Use definition list instead of table for bibliographic references.
-    # Join adjacent citation entries.
-
     def visit_citation(self, node):
+        # Use definition list for bibliographic references.
+        # Join adjacent citation entries.
+        # TODO: use <aside>.
         if not self.in_footnote_list:
-            self.body.append('<dl class="citation">\n')
+            listnode = node.copy()
+            listnode['ids'] = []
+            self.body.append(self.starttag(listnode, 'dl', CLASS='citation'))
+            # self.body.append('<dl class="citation">\n')
             self.in_footnote_list = True
 
     def depart_citation(self, node):
@@ -729,7 +733,7 @@ class HTMLTranslator(nodes.NodeVisitor):
         self.head.insert(0, self.content_type % self.settings.output_encoding)
         if 'name="dcterms.' in ''.join(self.meta):
             self.head.append(
-             '<link rel="schema.dcterms" href="http://purl.org/dc/terms/">')
+             '<link rel="schema.dcterms" href="http://purl.org/dc/terms/"/>')
         if self.math_header:
             if self.math_output == 'mathjax':
                 self.head.extend(self.math_header)
@@ -853,15 +857,16 @@ class HTMLTranslator(nodes.NodeVisitor):
         self.body_suffix[:0] = footer
         del self.body[start:]
 
-    # footnotes
-    # ---------
-    # use definition list instead of table for footnote text
-
-    # TODO: use the new HTML5 element <aside>? (Also for footnote text)
+    # TODO: use the new HTML5 element <aside> for footnote text
+    # (allows better styling with CSS, the current <dl> list styling
+    # with "float" interferes with sidebars).
     def visit_footnote(self, node):
         if not self.in_footnote_list:
+            listnode = node.copy()
+            listnode['ids'] = []
             classes = 'footnote ' + self.settings.footnote_references
-            self.body.append('<dl class="%s">\n'%classes)
+            self.body.append(self.starttag(listnode, 'dl', CLASS=classes))
+            # self.body.append('<dl class="%s">\n'%classes)
             self.in_footnote_list = True
 
     def depart_footnote(self, node):
@@ -905,19 +910,10 @@ class HTMLTranslator(nodes.NodeVisitor):
         self.header.extend(header)
         del self.body[start:]
 
-    # Image types to place in an <object> element
-    object_image_types = {'.swf': 'application/x-shockwave-flash'}
-
     def visit_image(self, node):
         atts = {}
         uri = node['uri']
-        ext = os.path.splitext(uri)[1].lower()
-        if ext in self.object_image_types:
-            atts['data'] = uri
-            atts['type'] = self.object_image_types[ext]
-        else:
-            atts['src'] = uri
-            atts['alt'] = node.get('alt', uri)
+        mimetype = mimetypes.guess_type(uri)[0]
         # image size
         if 'width' in node:
             atts['width'] = node['width']
@@ -966,12 +962,39 @@ class HTMLTranslator(nodes.NodeVisitor):
             suffix = '\n'
         if 'align' in node:
             atts['class'] = 'align-%s' % node['align']
-        if ext in self.object_image_types:
+        # Embed image file (embedded SVG or data URI):
+        if self.settings.embed_images or ('embed' in node):
+            err_msg = ''
+            if not mimetype:
+                err_msg = 'unknown MIME type'
+            if not self.settings.file_insertion_enabled:
+                err_msg = 'file insertion disabled.'
+            try:
+                with open(url2pathname(uri), 'rb') as imagefile:
+                    imagedata = imagefile.read()
+            except IOError as err:
+                err_msg = err.strerror
+            if err_msg:
+                self.document.reporter.error('Cannot embed image %r: %s'
+                                             %(uri, err_msg))
+            else:
+                self.settings.record_dependencies.add(
+                                            uri.replace('\\', '/'))
+                # TODO: insert SVG as-is?
+                # if mimetype == 'image/svg+xml':
+                  # read/parse, apply arguments,
+                  # insert as <svg ....> ... </svg> # (about 1/3 less data)
+                data64 = base64.b64encode(imagedata).decode()
+                uri = u'data:%s;base64,%s' % (mimetype, data64)
+        if mimetype == 'application/x-shockwave-flash':
+            atts['type'] = mimetype
             # do NOT use an empty tag: incorrect rendering in browsers
-            self.body.append(self.starttag(node, 'object', suffix, **atts) +
-                             node.get('alt', uri) + '</object>' + suffix)
+            tag = (self.starttag(node, 'object', '', data=uri, **atts)
+                   + node.get('alt', uri) + '</object>' + suffix)
         else:
-            self.body.append(self.emptytag(node, 'img', suffix, **atts))
+            atts['alt'] = node.get('alt', node['uri'])
+            tag = self.emptytag(node, 'img', suffix, src=uri, **atts)
+        self.body.append(tag)
 
     def depart_image(self, node):
         pass
@@ -1323,6 +1346,8 @@ class HTMLTranslator(nodes.NodeVisitor):
                    'References must have "refuri" or "refid" attribute.'
             atts['href'] = '#' + node['refid']
             atts['class'] += ' internal'
+        if len(node) == 1 and isinstance(node[0], nodes.image):
+            atts['class'] += ' image-reference'
         if not isinstance(node.parent, nodes.TextElement):
             assert len(node) == 1 and isinstance(node[0], nodes.image)
             atts['class'] += ' image-reference'
@@ -1353,7 +1378,6 @@ class HTMLTranslator(nodes.NodeVisitor):
     def depart_rubric(self, node):
         self.body.append('</p>\n')
 
-    # TODO: use the new HTML 5 element <section>?
     def visit_section(self, node):
         self.section_level += 1
         self.body.append(
@@ -1363,7 +1387,7 @@ class HTMLTranslator(nodes.NodeVisitor):
         self.section_level -= 1
         self.body.append('</div>\n')
 
-    # TODO: use the new HTML5 element <aside>? (Also for footnote text)
+    # TODO: use the new HTML5 element <aside>
     def visit_sidebar(self, node):
         self.body.append(
             self.starttag(node, 'div', CLASS='sidebar'))
@@ -1566,17 +1590,13 @@ class HTMLTranslator(nodes.NodeVisitor):
     def depart_title_reference(self, node):
         self.body.append('</cite>')
 
-    # TODO: use the new HTML5 element <aside>? (Also for footnote text)
     def visit_topic(self, node):
         self.body.append(self.starttag(node, 'div', CLASS='topic'))
         self.topic_classes = node['classes']
-        # TODO: replace with ::
-        #   self.in_contents = 'contents' in node['classes']
 
     def depart_topic(self, node):
         self.body.append('</div>\n')
         self.topic_classes = []
-        # TODO self.in_contents = False
 
     def visit_transition(self, node):
         self.body.append(self.emptytag(node, 'hr', CLASS='docutils'))
