@@ -8,5 +8,8 @@ parser_name = "rst"
 writer_name = "latex"
 
 # Extra setting we need
-settings_overrides['literal_block_env'] = 'verbatim'
 settings_overrides['syntax_highlight'] = 'none'
+settings_overrides['legacy_class_functions'] = False
+settings_overrides['stylesheet'] = 'docutils'
+
+settings_overrides['literal_block_env'] = 'verbatim'
