@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_tables.py 8367 2019-08-27 12:09:56Z milde $
+# $Id: test_tables.py 8497 2020-03-03 20:45:54Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -14,7 +14,9 @@ import sys
 import csv
 import platform
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__
+from test_parsers import DocutilsTestSupport
 from docutils.parsers.rst.directives import tables
 
 
@@ -43,10 +45,11 @@ else:
 # some error messages changed in Python 3.3, CPython has backported to 2.7.4,
 # PyPy has not
 csv_eod_error_str = 'unexpected end of data'
-if sys.version_info < (2,7,4) or platform.python_implementation() == 'PyPy':
+if sys.version_info < (2,7,4) or (platform.python_implementation() == 'PyPy'
+                                  and sys.version_info < (3,0)):
     csv_eod_error_str = 'newline inside string'
 # pypy adds a line number
-if sys.version_info >= (3, 0) and platform.python_implementation() == 'PyPy':
+if platform.python_implementation() == 'PyPy':
     csv_eod_error_str = 'line 1: ' + csv_eod_error_str
 csv_unknown_url = "'bogus.csv'"
 if sys.version_info < (3, 0):
