@@ -1,14 +1,18 @@
 #! /usr/bin/env python
 
-# $Id: test_field_lists.py 8172 2017-08-17 22:28:42Z goodger $
+# $Id: test_field_lists.py 8481 2020-01-31 08:17:24Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
 """
 Tests for states.py.
 """
+from __future__ import absolute_import
+
+if __name__ == '__main__':
+    import __init__
+from test_parsers import DocutilsTestSupport
 
-from __init__ import DocutilsTestSupport
 
 def suite():
     s = DocutilsTestSupport.ParserTestSuite()
