@@ -1,7 +1,7 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
 
-# $Id: test_inline_markup.py 8356 2019-08-26 16:44:19Z milde $
+# $Id: test_inline_markup.py 8481 2020-01-31 08:17:24Z milde $
 # Author: David Goodger <goodger@python.org>
 # Copyright: This module has been placed in the public domain.
 
@@ -11,7 +11,9 @@ Interpreted text tests are in a separate module, test_interpreted.py.
 """
 from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__
+from test_parsers import DocutilsTestSupport
 
 
 def suite():
