@@ -1,6 +1,6 @@
 #! /usr/bin/env python
 
-# $Id: test_strip_elements_with_class.py 8385 2019-09-06 13:16:07Z milde $
+# $Id: test_strip_elements_with_class.py 8481 2020-01-31 08:17:24Z milde $
 # Author: Guenter Milde <milde@users.sf.net>
 # Copyright: This module has been placed in the public domain.
 
@@ -9,7 +9,9 @@ Tests for docutils.transforms.universal.StripClassesAndElements.
 """
 from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__
+from test_transforms import DocutilsTestSupport
 from docutils.parsers.rst import Parser
 from docutils.transforms.universal import StripClassesAndElements
 
