@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# $Id: test_pseudoxml.py 8356 2019-08-26 16:44:19Z milde $
+# $Id: test_pseudoxml.py 8481 2020-01-31 08:17:24Z milde $
 # Author: Lea Wiemann <LeWiemann@gmail.com>
 # Copyright: This module has been placed in the public domain.
 
@@ -9,7 +9,9 @@ Test for pseudo-XML writer.
 """
 from __future__ import absolute_import
 
-from . import DocutilsTestSupport
+if __name__ == '__main__':
+    import __init__
+from test_writers import DocutilsTestSupport
 
 
 def suite():
